PATH_AVG_FILES = "ftp/thies/BINFILES/ARCH_AV1"
PATH_EXT_FILES = "ftp/thies/BINFILES/ARCH_EX1"
DRIVE_ID = "b!Row14jaFrU-1q8qzrvj3OmPPTYWXizFEpJmI-wsfH5pXxA0qQwgQS50m2xvPCZem"
FILE_TYPES = ["AVG", "EXT"]
